pub struct PatternMatcherFactory;Expand description
Factory for creating the most appropriate pattern matcher based on the pattern and available hardware capabilities.
Implementations
Sourceimpl PatternMatcherFactory
impl PatternMatcherFactory
Sourcepub fn create(pattern: &str) -> Box<dyn PatternMatcher + Send + Sync>
pub fn create(pattern: &str) -> Box<dyn PatternMatcher + Send + Sync>
Creates the most optimized pattern matcher for the given pattern.
This will automatically select between:
- SIMD-accelerated literal matcher for simple patterns (when hardware supports it)
- Standard literal matcher for simple patterns (fallback)
- Regex matcher for complex patterns